@@ -15,7 +15,10 @@
 
 import xml.etree.ElementTree as ET
 
+import pytest
+
 from asciidoxy.parser.doxygen.description_parser import (
+    UNSUPPORTED,
     Admonition,
     DescriptionElement,
     NestedDescriptionElement,
@@ -40,6 +43,37 @@ def parse(input_xml):
     return output
 
 
+def test_parse_unknown_element():
+    input_xml = """\
+        <detaileddescription>
+<para>Text before. <unknown>Text inside unsupported inline tag.</unknown> Text after.
+<unknown>Text inside unsupported tag.</unknown></para>
+<para>Paragraph after.</para>
+        </detaileddescription>
+"""
+    output = parse(input_xml)
+    assert output.to_asciidoc() == """\
+Text before.  Text after.
+
+Paragraph after."""
+
+
+@pytest.mark.parametrize("tag_name", UNSUPPORTED.keys())
+def test_parse_unsupported_element(tag_name):
+    input_xml = f"""\
+        <detaileddescription>
+<para>Text before. <{tag_name}>Text inside unsupported inline tag.</{tag_name}> Text after.
+<{tag_name}>Text inside unsupported tag.</{tag_name}></para>
+<para>Paragraph after.</para>
+        </detaileddescription>
+"""
+    output = parse(input_xml)
+    assert output.to_asciidoc() == """\
+Text before.  Text after.
+
+Paragraph after."""
+
+
 def test_parse_styles():
     input_xml = """\
         <detaileddescription>
@@ -832,7 +866,7 @@ Combining ordered and unordered lists.
 * NetBSD"""
 
 
-def test_parse_failure():
+def test_parse_ref_in_parameter():
     input_xml = """\
 <detaileddescription>
 <para><parameterlist kind="param"><parameteritem>
@@ -896,6 +930,66 @@ def test_parse_failure():
     assert not output.to_asciidoc()
 
 
+def test_parse_ref_in_description():
+    input_xml = """\
+    <detaileddescription>
+<para><ref refid="classasciidoxy_1_1descriptions_1_1_links" kindref="compound">Links</ref> to other elements.</para>
+<para>Some other test classes are: <itemizedlist>
+<listitem><para><ref refid="classasciidoxy_1_1descriptions_1_1_code_block" kindref="compound">CodeBlock</ref> for code blocks. </para>
+</listitem>
+<listitem><para><ref refid="classasciidoxy_1_1descriptions_1_1_diagrams" kindref="compound">Diagrams</ref> for plantUML and Dot. </para>
+</listitem>
+<listitem><para><ref refid="classasciidoxy_1_1descriptions_1_1_sections" kindref="compound">Sections</ref> for all kinds of sections.</para>
+</listitem>
+</itemizedlist>
+Of course there is also <ref refid="descriptions_8hpp_1ac2b05985028362b43839a108f8b30a24" kindref="member">FunctionDocumentation()</ref>. </para>
+    </detaileddescription>
+"""
+    output = parse(input_xml)
+    assert output.to_asciidoc() == """\
+<<lang-classasciidoxy_1_1descriptions_1_1_links,Links>> to other elements.
+
+Some other test classes are:
+
+* <<lang-classasciidoxy_1_1descriptions_1_1_code_block,CodeBlock>> for code blocks.
+
+* <<lang-classasciidoxy_1_1descriptions_1_1_diagrams,Diagrams>> for plantUML and Dot.
+
+* <<lang-classasciidoxy_1_1descriptions_1_1_sections,Sections>> for all kinds of sections.
+
+Of course there is also <<lang-descriptions_8hpp_1ac2b05985028362b43839a108f8b30a24,FunctionDocumentation()>>."""
+
+
+def test_parse_ref__asciidoctor_anchor_bug_workaround_2746():
+    input_xml = """\
+    <detaileddescription>
+<para><ref refid="class__asciidoxy_1_1descriptions_1_1_links" kindref="compound">Links</ref> to other elements.</para>
+<para>Some other test classes are: <itemizedlist>
+<listitem><para><ref refid="classasciidoxy_1_1descrip__tions_1_1_code_block" kindref="compound">CodeBlock</ref> for code blocks. </para>
+</listitem>
+<listitem><para><ref refid="classasciidoxy_1_1descriptions_1_1_diagrams" kindref="compound">Diagrams</ref> for plantUML and Dot. </para>
+</listitem>
+<listitem><para><ref refid="classasciidoxy_1_1descriptions_1_1_sections" kindref="compound">Sections</ref> for all kinds of sections.</para>
+</listitem>
+</itemizedlist>
+Of course there is also <ref refid="descriptions_8hpp_1ac2b05985028362b43839a108f8b30a24" kindref="member">FunctionDocumentation()</ref>. </para>
+    </detaileddescription>
+"""
+    output = parse(input_xml)
+    assert output.to_asciidoc() == """\
+<<lang-class-asciidoxy_1_1descriptions_1_1_links,Links>> to other elements.
+
+Some other test classes are:
+
+* <<lang-classasciidoxy_1_1descrip-tions_1_1_code_block,CodeBlock>> for code blocks.
+
+* <<lang-classasciidoxy_1_1descriptions_1_1_diagrams,Diagrams>> for plantUML and Dot.
+
+* <<lang-classasciidoxy_1_1descriptions_1_1_sections,Sections>> for all kinds of sections.
+
+Of course there is also <<lang-descriptions_8hpp_1ac2b05985028362b43839a108f8b30a24,FunctionDocumentation()>>."""
+
+
 def test_parse_code_blocks_no_newlines():
     input_xml = """\
     <detaileddescription>
